@@ -4,9 +4,15 @@
 
 ;; Author: KOSEKI Yoshinori <kose@meadowy.org>
 
-(unless (file-exists-p skk-large-jisyo)
+(cond
+ ((null skk-large-jisyo)
   (setq skk-large-jisyo (expand-file-name "etc/skk/SKK-JISYO.L" 
 					  netinstall-pkg-dir)))
+ ((listp skk-large-jisyo)
+  )
+ ((not (file-exists-p skk-large-jisyo))
+  (setq skk-large-jisyo (expand-file-name "etc/skk/SKK-JISYO.L" 
+					  netinstall-pkg-dir))))
 
 (unless (file-exists-p skk-tut-file)
   (setq skk-tut-file (expand-file-name "etc/skk/SKK.tut" 
